Platforms class

Platforms implementation using dart:io. Used on VM and native platforms where dart:io is available. Do not use on web; use conditional export so web gets platforms_stub.dart instead.

Constructors

Platforms()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isAndroid bool
no setter
isFuchsia bool
no setter
isIOS bool
no setter
isLinux bool
no setter
isMacOS bool
no setter
isWeb bool
no setter
isWindows bool
no setter
operatingSystem String
no setter
operatingSystemVersion String
no setter
platformName String
no setter

Static Methods

injectToUrl(String url) String