ScrollableAreaArrows class

ScrollableAreaArrows is a class that can be used to show or hide the arrows

Constructors

ScrollableAreaArrows({bool top = true, bool bottom = true, bool start = true, bool end = true, double margin = 10})
const
ScrollableAreaArrows.all(bool visibility, {double margin = 10})
factory
ScrollableAreaArrows.only({bool top = false, bool bottom = false, bool start = false, bool end = false, double margin = 10})
only
factory
ScrollableAreaArrows.symmetric(bool vertical, bool horizontal, {double margin = 10})
factory

Properties

bottom → bool
final
end → bool
final
hashCode → int
The hash code for this object.
no setterinherited
margin → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → bool
final
top → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited